
## CATO-CLI - mutation.enterpriseDirectory.archiveLocation:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.enterpriseDirectory.archiveLocation) for documentation on this operation.

### Usage for mutation.enterpriseDirectory.archiveLocation:

```bash
catocli mutation enterpriseDirectory archiveLocation -h

catocli mutation enterpriseDirectory archiveLocation <json>

catocli mutation enterpriseDirectory archiveLocation --json-file mutation.enterpriseDirectory.archiveLocation.json

catocli mutation enterpriseDirectory archiveLocation '{"locationId":"id"}'

catocli mutation enterpriseDirectory archiveLocation '{
    "locationId": "id"
}'
```

#### Operation Arguments for mutation.enterpriseDirectory.archiveLocation ####

`accountId` [ID] - (required) N/A    
`locationId` [ID] - (required) N/A    
